=== modified file 'init/main.c'
--- init/main.c	2012-12-17 15:53:39 +0000
+++ init/main.c	2012-12-17 17:27:32 +0000
@@ -68,6 +68,7 @@
 #include "conf.h"
 #include "control.h"
 #include "state.h"
+#include "xdg.h"
 
 
 /* Prototypes for static functions */
@@ -86,6 +87,7 @@
 
 static void handle_confdir      (void);
 static void handle_logdir       (void);
+static void handle_usermode     (void);
 static int  console_type_setter (NihOption *option, const char *arg);
 
 
@@ -124,7 +126,7 @@
  *
  * If TRUE, upstart runs in user session mode.
  **/
-static int user_mode = 0;
+static int user_mode = FALSE;
 
 extern int          disable_sessions;
 extern int          disable_job_logging;
@@ -186,6 +188,7 @@
       char *argv[])
 {
 	char **args = NULL;
+	char **dirs = NULL;
 	int    ret;
 
 	args_copy = NIH_MUST (nih_str_array_copy (NULL, NULL, argv));
@@ -204,6 +207,7 @@
 
 	handle_confdir ();
 	handle_logdir ();
+	handle_usermode ();
 
 	if (disable_job_logging)
 		nih_debug ("Job logging disabled");
@@ -529,8 +533,18 @@
 	}
 
 	/* Read configuration */
-	NIH_MUST (conf_source_new (NULL, CONFFILE, CONF_FILE));
-	NIH_MUST (conf_source_new (NULL, conf_dir, CONF_JOB_DIR));
+	if (! user_mode)
+		NIH_MUST (conf_source_new (NULL, CONFFILE, CONF_FILE));
+
+	if (conf_dir)
+		NIH_MUST (conf_source_new (NULL, conf_dir, CONF_JOB_DIR));
+
+	if (user_mode) {
+		dirs = get_user_upstart_dirs();
+		for (char **d = dirs; d && *d; d++)
+			NIH_MUST (conf_source_new (NULL, *d, CONF_JOB_DIR));
+		nih_free (dirs);
+	}
 
 	conf_reload ();
 
@@ -913,6 +927,9 @@
 	if (conf_dir)
 		goto out;
 
+	if (user_mode)
+		return;
+
 	conf_dir = CONFDIR;
 
 	dir = getenv (CONFDIR_ENV);
@@ -953,6 +970,18 @@
 			log_dir);
 }
 
+/**
+ * handle_usermode:
+ *
+ * Setup user session mode.
+ **/
+static void
+handle_usermode (void)
+{
+	if (user_mode)
+		use_session_bus = TRUE;
+}
+
 /**  
  * NihOption setter function to handle selection of default console
  * type.

